#!/usr/bin/python
#
# Copyright 2014 Canonical Ltd.  All rights reserved
# Author: Chris Stratford <chris.stratford@canonical.com>

import sys
import os
sys.path.insert(0, os.path.join(os.environ['CHARM_DIR'], 'lib'))
from charmhelpers.core.hookenv import config, log

class Config:
    def app_name(self):
        return str(config("application_name"))

    def dailyRun(self):
        values = {"no": "no", "yes": "yes"}
        return self.valueMap("daily_run", values)
        
    def devFiles(self):
        return self.getConfig("dev_files")

    def hiddenDirs(self):
        return self.getConfig("hidden_dirs")

    def hiddenFiles(self):
        return self.getConfig("hidden_files")

    def getConfig(self, what, default=""):
        if config(what):
            return config(what)
        else:
            return default

    def logFile(self):
        return self.getConfig("logfile")

    def mailRecipient(self):
        return self.getConfig("mail_recipient")

    def mirrorAccess(self):
        values = {"priority": 0, "rotate": 1}
        return self.valueMap("mirror_access", values)

    def mirrorList(self):
        return self.getConfig("mirror_list").split()

    def mirrorMode(self):
        values = {"any": 0, "local": 1, "remote": 2}
        return self.valueMap("mirror_mode", values)

    def mirrorUpdate(self):
        values = {"no": 1, "yes": 1}
        return self.valueMap("mirror_update", values)

    def scriptDir(self):
        return self.getConfig("script_dir")

    def scriptWhitelist(self):
        return self.getConfig("script_whitelist")

    def sshRootAllowed(self):
        values = {"no": "no", "yes": "yes"}
        return self.valueMap("ssh_root_allowed", values)

    # Map juju config values to rkhunter config values
    # Setting an invalid value will cause a juju config-changed error
    def valueMap(self, key, values):
        if self.getConfig(key) in values:
            return values[self.getConfig(key)]
        else:
            log("CHARM: Configuration error: '{}' is not a valid option for {}".format(self.getConfig(key), key))
            sys.exit(1)

    def weeklyDbUpdate(self):
        values = {"no": "no", "yes": "yes"}
        return self.valueMap("weekly_db_update", values)
